@@ -74,10 +74,6 @@ modelName <- function(object, ...) UseMethod("modelName")
 #' @export modelType
 modelType <- function(object, ...) UseMethod("modelType")
 
-modelLags <- function(object, ...) UseMethod("modelLags")
-
-smoothType <- function(object, ...) UseMethod("smoothType")
-
 ##### Likelihood function and stuff #####
 
 #' @importFrom greybox AICc
@@ -987,11 +983,14 @@ errorType.smooth <- function(object, ...){
 errorType.smooth.sim <- errorType.smooth;
 
 ##### Function returns the modelLags from the model - internal function #####
-modelLags.default <- function(object, ...){
+modelLags <- function(object, ...){
     modelLags <- NA;
     if(is.msarima(object)){
         modelLags <- object$modelLags;
     }
+    else if(is.adam(object)){
+        modelLags <- object$lagsAll;
+    }
     else{
         smoothType <- smoothType(object);
         if(smoothType=="ETS"){
@@ -1709,7 +1708,9 @@ plot.smooth <- function(x, which=c(1,2,4,6), level=0.95, legend=FALSE,
                 theValues <- pacf(as.vector(residuals(x)), plot=FALSE, na.action=na.pass);
             }
         }
-        ellipsis$x <- theValues$acf[-1];
+        ellipsis$x <- switch(type,
+                             "acf"=theValues$acf[-1],
+                             "pacf"=theValues$acf);
         statistic <- qnorm(c((1-level)/2, (1+level)/2),0,sqrt(1/nobs(x)));
 
         ellipsis$type <- "h"
@@ -2611,11 +2612,7 @@ simulate.smooth <- function(object, nsim=1, seed=NULL, obs=NULL, ...){
 }
 
 #### Type of smooth model. Internal function ####
-smoothType.default <- function(object, ...){
-    return(NA);
-}
-
-smoothType.smooth <- function(object, ...){
+smoothType <- function(object, ...){
     if(!is.list(object$model)){
         if(gregexpr("ETS",object$model)!=-1){
             smoothType <- "ETS";
@@ -2649,8 +2646,6 @@ smoothType.smooth <- function(object, ...){
     return(smoothType);
 }
 
-smoothType.smooth.sim <- smoothType.smooth;
-
 #### Summary of objects ####
 #' @export
 summary.smooth <- function(object, ...){
